Module: Skyline::Positionable
- Included in:
- Page
- Defined in:
- lib/skyline/positionable.rb
Overview
Positionable automatically adds the last position number to ActiveRecord models
in the position column. It only set's the position if it isn't set yet.
By defining an optional scope the position numbering will only look inside a certain scope.
Defined Under Namespace
Modules: ClassMethods